==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Выполнено</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>Ограничение оси...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>задать ось ограниченную двумя объектами</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Самотестирование ...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Выполняет самопроверку для проверки правильности функционирования приложения</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>Рисование</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>Наборосок</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>&amp;Трассировка лучей</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>&amp;Черчение</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>Основанный на эскизе</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Примитивы</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Параметрический</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Внешность объекта</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Проволочные инструменты</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Выполнено</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Ограничение оси...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>задать ось ограниченную двумя объектами</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Самотестирование ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Выполняет самопроверку для проверки правильности функционирования приложения</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>Рисование</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>Наборосок</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Трассировка лучей</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>&amp;Черчение</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>Основанный на эскизе</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Примитивы</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Параметрический</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Внешность объекта</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Проволочные инструменты</translation>
    </message>
  </context>
</TS>
